import caesar3
import unittest

class KnownEncryptions(unittest.TestCase):
    known_encryptions = (   ('hello', 2, 'jgnnq'),
                            ('plain', 5, 'uqfns'),
                            ('abcde', 1, 'bcdef'),
                            ('zoo', 4, 'dss'),
                            ('xylophone', 14, 'lmzcdvcbs'),
                            ('HELLO', 2, 'JGNNQ'),
                            ('XyLoPhOnE', 14, 'LmZcDvCbS'),
                            ('hello', -2, 'fcjjm'),
                            ('AnAcOnDa', -20, 'GtGiUtJg'))
    def test_caesar_known_encryptions(self):
        '''encrypt should give known result with known input'''
        for plaintext, shift, ciphertext in self.known_encryptions:
            result = caesar3.encrypt(plaintext, shift)
            self.assertEqual(result, ciphertext)

    def test_caesar_known_decryptions(self):
        '''decrypt should give known result with known input'''
        for plaintext, shift, ciphertext in self.known_encryptions:
            result = caesar3.decrypt(ciphertext, shift)
            self.assertEqual(result, plaintext)

class EncryptAndDecrypt(unittest.TestCase):
   plaintext = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'

   def test_encrypt_and_decrypt(self):
       '''decrypt(encrypt(string, n)) == string for all strings and all n'''
       for i in range(-25, 26):
           self.assertEqual(self.plaintext, caesar3.decrypt(caesar3.encrypt(self.plaintext, i), i))

if __name__ == '__main__':
    unittest.main()
